==> hordelib-1.6.2.tar.gz: hordelib-1.6.2/tests/test_horde_samplers.py <==
# test_horde.py
import os

import pytest
from PIL import Image

from hordelib.horde import HordeLib

from .testing_shared_functions import CosineSimilarityResultCode, check_single_inference_image_similarity

SLOW_SAMPLERS = ["k_dpmpp_2s_a", "k_dpmpp_sde", "k_heun", "k_dpm_2", "k_dpm_2_a"]


class TestHordeSamplers:
    def test_samplers(
        self,
        stable_diffusion_modelname_for_testing: str,
        hordelib_instance: HordeLib,
    ):
        data = {
            "sampler_name": "",
            "cfg_scale": 6.5,
            "denoising_strength": 1.0,
            "seed": 3688490319,
            "height": 512,
            "width": 512,
            "karras": False,
            "tiling": False,
            "hires_fix": False,
            "clip_skip": 1,
            "control_type": None,
            "image_is_control": False,
            "return_control_map": False,
            "prompt": (
                "a woman closeup made out of metal, (cyborg:1.1), realistic skin, (detailed wire:1.3), "
                "(intricate details), hdr, (intricate details, hyperdetailed:1.2), cinematic shot, "
                "vignette, centered"
            ),
            "ddim_steps": 30,
            "n_iter": 1,
            "model": stable_diffusion_modelname_for_testing,
        }
        images_to_compare: list[tuple[str, Image.Image]] = []
        for sampler in HordeLib.SAMPLERS_MAP.keys():
            data["sampler_name"] = sampler.upper()  # force uppercase to ensure case insensitive

            pil_image = hordelib_instance.basic_inference(data)
            assert pil_image is not None

            img_filename = f"sampler_30_steps_{sampler}.png"
            pil_image.save(f"images/{img_filename}", quality=100)
            images_to_compare.append((f"images_expected/{img_filename}", pil_image))

        for img_filename, pil_image in images_to_compare:
            assert check_single_inference_image_similarity(
                img_filename,
                pil_image,
            )

    def test_slow_samplers(
        self,
        stable_diffusion_modelname_for_testing: str,
        hordelib_instance: HordeLib,
    ):
        data = {
            "sampler_name": "",
            "cfg_scale": 6.5,
            "denoising_strength": 1.0,
            "seed": 3688390309,
            "height": 512,
            "width": 512,
            "karras": False,
            "tiling": False,
            "hires_fix": False,
            "clip_skip": 1,
            "control_type": None,
            "image_is_control": False,
            "return_control_map": False,
            "prompt": (
                "an old man closeup, (hr giger:1.1), (detailed wire:1.3), "
                "(intricate details), hdr, (intricate details, hyperdetailed:1.2), cinematic shot, "
                "vignette, centered"
            ),
            "ddim_steps": 10,
            "n_iter": 1,
            "model": stable_diffusion_modelname_for_testing,
        }

        images_to_compare: list[tuple[str, Image.Image]] = []
        for sampler in SLOW_SAMPLERS:
            data["sampler_name"] = sampler

            pil_image = hordelib_instance.basic_inference(data)
            assert pil_image is not None

            img_filename = f"sampler_10_steps_{sampler}.png"
            pil_image.save(f"images/{img_filename}", quality=100)
            images_to_compare.append((f"images_expected/{img_filename}", pil_image))

        for img_filename, pil_image in images_to_compare:
            assert check_single_inference_image_similarity(
                img_filename,
                pil_image,
            )

==> hordelib-1.6.4.tar.gz: hordelib-1.6.4/tests/test_horde_samplers.py <==
# test_horde.py
import os

import pytest
from PIL import Image

from hordelib.horde import HordeLib

from .testing_shared_functions import CosineSimilarityResultCode, check_single_inference_image_similarity

SLOW_SAMPLERS = ["k_dpmpp_2s_a", "k_dpmpp_sde", "k_heun", "k_dpm_2", "k_dpm_2_a"]


class TestHordeSamplers:
    def test_samplers(
        self,
        stable_diffusion_model_name_for_testing: str,
        hordelib_instance: HordeLib,
    ):
        data = {
            "sampler_name": "",
            "cfg_scale": 6.5,
            "denoising_strength": 1.0,
            "seed": 3688490319,
            "height": 512,
            "width": 512,
            "karras": False,
            "tiling": False,
            "hires_fix": False,
            "clip_skip": 1,
            "control_type": None,
            "image_is_control": False,
            "return_control_map": False,
            "prompt": (
                "a woman closeup made out of metal, (cyborg:1.1), realistic skin, (detailed wire:1.3), "
                "(intricate details), hdr, (intricate details, hyperdetailed:1.2), cinematic shot, "
                "vignette, centered"
            ),
            "ddim_steps": 30,
            "n_iter": 1,
            "model": stable_diffusion_model_name_for_testing,
        }
        images_to_compare: list[tuple[str, Image.Image]] = []
        for sampler in HordeLib.SAMPLERS_MAP.keys():
            data["sampler_name"] = sampler.upper()  # force uppercase to ensure case insensitive

            pil_image = hordelib_instance.basic_inference(data)
            assert pil_image is not None

            img_filename = f"sampler_30_steps_{sampler}.png"
            pil_image.save(f"images/{img_filename}", quality=100)
            images_to_compare.append((f"images_expected/{img_filename}", pil_image))

        for img_filename, pil_image in images_to_compare:
            assert check_single_inference_image_similarity(
                img_filename,
                pil_image,
            )

    def test_slow_samplers(
        self,
        stable_diffusion_model_name_for_testing: str,
        hordelib_instance: HordeLib,
    ):
        data = {
            "sampler_name": "",
            "cfg_scale": 6.5,
            "denoising_strength": 1.0,
            "seed": 3688390309,
            "height": 512,
            "width": 512,
            "karras": False,
            "tiling": False,
            "hires_fix": False,
            "clip_skip": 1,
            "control_type": None,
            "image_is_control": False,
            "return_control_map": False,
            "prompt": (
                "an old man closeup, (hr giger:1.1), (detailed wire:1.3), "
                "(intricate details), hdr, (intricate details, hyperdetailed:1.2), cinematic shot, "
                "vignette, centered"
            ),
            "ddim_steps": 10,
            "n_iter": 1,
            "model": stable_diffusion_model_name_for_testing,
        }

        images_to_compare: list[tuple[str, Image.Image]] = []
        for sampler in SLOW_SAMPLERS:
            data["sampler_name"] = sampler

            pil_image = hordelib_instance.basic_inference(data)
            assert pil_image is not None

            img_filename = f"sampler_10_steps_{sampler}.png"
            pil_image.save(f"images/{img_filename}", quality=100)
            images_to_compare.append((f"images_expected/{img_filename}", pil_image))

        for img_filename, pil_image in images_to_compare:
            assert check_single_inference_image_similarity(
                img_filename,
                pil_image,
            )
